@@ -19,6 +19,7 @@ from cbw_api_toolbox.__routes__ import ROUTE_APPLICATIVE_SCANS
 from cbw_api_toolbox.__routes__ import ROUTE_COMPLIANCE_RULES
 from cbw_api_toolbox.__routes__ import ROUTE_COMPLIANCE_ASSETS
 from cbw_api_toolbox.__routes__ import ROUTE_CVE_ANNOUNCEMENTS
+from cbw_api_toolbox.__routes__ import ROUTE_DISCOVERY
 from cbw_api_toolbox.__routes__ import ROUTE_DOCKER_IMAGES
 from cbw_api_toolbox.__routes__ import ROUTE_GROUPS
 from cbw_api_toolbox.__routes__ import ROUTE_HOSTS
@@ -42,11 +43,13 @@ class CBWApi: # pylint: disable=R0904
         api_url=None,
         api_key=None,
         secret_key=None,
+        proxies = None,
         verify_ssl=False,
     ):
 
         self.verify_ssl = verify_ssl
         self.logger = logging.getLogger(self.__class__.__name__)
+        self.proxies = proxies
 
         try:
             self.api_url = api_url if api_url is not None else environ["CBW_API_URL"]
@@ -85,6 +88,7 @@ class CBWApi: # pylint: disable=R0904
                 route,
                 data=body_params,
                 params=params,
+                proxies=self.proxies,
                 auth=CBWAuth(self.api_key, self.secret_key),
                 verify=self.verify_ssl)
 
@@ -110,14 +114,14 @@ class CBWApi: # pylint: disable=R0904
 
         if 'page' in params:
             response = self._request(verb, route, params)
-            if response.status_code != 200:
+            if not response.ok:
                 logging.error("Error::{}".format(response.text))
                 return None
             return self._cbw_parser(response)
 
         response = self._request(verb, route, params)
 
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -133,7 +137,7 @@ class CBWApi: # pylint: disable=R0904
     @staticmethod
     def verif_response(response):
         """Check the response status code"""
-        if response.status_code >= 200 and response.status_code <= 299:
+        if response.ok:
             logging.debug("response server OK::{}".format(response.text))
             return True
 
@@ -160,7 +164,7 @@ class CBWApi: # pylint: disable=R0904
         """GET request to /api/v3/server/{server_id} to get all informations
         about a specific server"""
         response = self._request("GET", [ROUTE_SERVERS, server_id])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error server id::{}".format(response.text))
             return None
         return self._cbw_parser(response)
@@ -169,7 +173,7 @@ class CBWApi: # pylint: disable=R0904
         """PUT request to /api/v3/server/{server_id}/refresh to relaunch analysis
         script on a specific server"""
         response = self._request("PUT", [ROUTE_SERVERS, server_id, 'refresh'])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error server id::{}".format(response.text))
             return None
 
@@ -190,7 +194,7 @@ class CBWApi: # pylint: disable=R0904
     def server_schedule_updates(self, server_id, params=None):
         """POST request to /api/v3/server/<server_id>/updates to install fixes"""
         response = self._request("POST", [ROUTE_SERVERS, server_id, "updates"], params)
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -209,7 +213,7 @@ class CBWApi: # pylint: disable=R0904
     def update_server_cve(self, server_id, cve_code, params=None):
         """PUT request to /api/v3/server/<server_id>/cve_announcements/<cve_code> to update a server cve"""
         response = self._request("PUT", [ROUTE_SERVERS, server_id, "cve_announcements", cve_code], params)
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -224,7 +228,7 @@ class CBWApi: # pylint: disable=R0904
         """GET request to /api/v3/agents/{agent_id} to get all informations
         about a specific agent"""
         response = self._request("GET", [ROUTE_AGENTS, agent_id])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error agent id::{}".format(response.text))
             return None
         return self._cbw_parser(response)
@@ -276,7 +280,7 @@ class CBWApi: # pylint: disable=R0904
         about a specific remote access"""
         response = self._request("GET", [ROUTE_REMOTE_ACCESSES, remote_access_id])
 
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("error remote_access_id::{}".format(response.text))
             return None
 
@@ -306,7 +310,7 @@ class CBWApi: # pylint: disable=R0904
         """GET request to /api/v3/cve_announcements/{cve_code} to get all informations
         about a specific cve_announcement"""
         response = self._request("GET", [ROUTE_CVE_ANNOUNCEMENTS, cve_code])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error server id::{}".format(response.text))
             return None
 
@@ -322,7 +326,7 @@ class CBWApi: # pylint: disable=R0904
         """PUT request to /api/v3/cve_announcements/{cve_code} to update cvss_custom/score_custom informations
         about a specific cve_announcement"""
         response = self._request("PUT", [ROUTE_CVE_ANNOUNCEMENTS, cve_code], params)
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error server id::{}".format(response.text))
             return None
 
@@ -332,7 +336,7 @@ class CBWApi: # pylint: disable=R0904
         """DELETE request to /api/v3/cve_announcements/{cve_code} to delete
          a cvss_custom/score_custom fields of a cve_announcement"""
         response = self._request("DELETE", [ROUTE_CVE_ANNOUNCEMENTS, cve_code])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error server id::{}".format(response.text))
             return None
 
@@ -347,7 +351,7 @@ class CBWApi: # pylint: disable=R0904
     def group(self, group_id):
         """GET request to /api/v3/groups/<group_id> to get a specific group"""
         response = self._request("GET", [ROUTE_GROUPS, group_id])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -365,7 +369,7 @@ class CBWApi: # pylint: disable=R0904
     def update_group(self, group_id, params=None):
         """PUT request to /api/v3/groups/<group_id> to update a group"""
         response = self._request("PUT", [ROUTE_GROUPS, group_id], params)
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -374,7 +378,7 @@ class CBWApi: # pylint: disable=R0904
     def delete_group(self, group_id):
         """DELETE request to /api/v3/groups/<group_id> to delete a group"""
         response = self._request("DELETE", [ROUTE_GROUPS, group_id])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -383,7 +387,7 @@ class CBWApi: # pylint: disable=R0904
     def test_deploy_remote_access(self, remote_access_id):
         """POST request to /api/v3/remote_accesses/:id/test_deploy to test an agentless deployment"""
         response = self._request("PUT", [ROUTE_REMOTE_ACCESSES, remote_access_id, 'test_deploy'])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
         return self._cbw_parser(response)
@@ -398,7 +402,7 @@ class CBWApi: # pylint: disable=R0904
         """GET request to /api/v3/users/<id> to get a specific user"""
         response = self._request("GET", [ROUTE_USERS, user_id])
 
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -413,7 +417,7 @@ class CBWApi: # pylint: disable=R0904
     def node(self, node_id):
         """GET request to /api/v3/nodes/<node_id> to get a list of all nodes"""
         response = self._request("GET", [ROUTE_NODES, node_id])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -422,7 +426,7 @@ class CBWApi: # pylint: disable=R0904
     def delete_node(self, node_id, new_node_id):
         """DELETE request to /api/v3/nodes/<node_id> to delete a node and transfer the data to another one"""
         response = self._request("DELETE", [ROUTE_NODES, node_id], new_node_id)
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -437,7 +441,7 @@ class CBWApi: # pylint: disable=R0904
     def host(self, host_id):
         """GET request to /api/v3/hosts/<host_id> to get a specific host"""
         response = self._request("GET", [ROUTE_HOSTS, host_id])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -455,7 +459,7 @@ class CBWApi: # pylint: disable=R0904
     def update_host(self, host_id, params=None):
         """PUT request to /api/v3/hosts/<host_id> to update a host"""
         response = self._request("PUT", [ROUTE_HOSTS, host_id], params)
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -464,7 +468,7 @@ class CBWApi: # pylint: disable=R0904
     def delete_host(self, host_id):
         """DELETE request to /api/v3/hosts/<host_id> to delete a host"""
         response = self._request("DELETE", [ROUTE_HOSTS, host_id])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -479,7 +483,7 @@ class CBWApi: # pylint: disable=R0904
     def security_issue(self, security_issue_id):
         """GET request to /api/v3/security_issues/<security_issue_id> to get a specific security_issue"""
         response = self._request("GET", [ROUTE_SECURITY_ISSUES, security_issue_id])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -497,7 +501,7 @@ class CBWApi: # pylint: disable=R0904
     def update_security_issue(self, security_issue_id, params=None):
         """PUT request to /api/v3/security_issues/<security_issue_id> to update a security_issue"""
         response = self._request("PUT", [ROUTE_SECURITY_ISSUES, security_issue_id], params)
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -506,7 +510,7 @@ class CBWApi: # pylint: disable=R0904
     def delete_security_issue(self, security_issue_id):
         """DELETE request to /api/v3/security_issues/<security_issue_id> to delete a security_issue"""
         response = self._request("DELETE", [ROUTE_SECURITY_ISSUES, security_issue_id])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -515,7 +519,7 @@ class CBWApi: # pylint: disable=R0904
     def fetch_airgapped_scripts(self, params=None):
         """GET request to /api/v2/cbw_scans/scripts to get a list of all air gapped scanning scripts"""
         response = self._request("GET", [ROUTE_AIRGAPPED_SCRIPTS], params)
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -524,7 +528,7 @@ class CBWApi: # pylint: disable=R0904
     def fetch_airgapped_script(self, script_id, params=None):
         """GET request to /api/v2/cbw_scans/scripts/{SCRIPT_ID} to get a specific air gapped scanning script"""
         response = self._request("GET", [ROUTE_AIRGAPPED_SCRIPTS, script_id], params=params)
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error for script with id {} :: {}".format(script_id, response.text))
             return None
 
@@ -533,7 +537,7 @@ class CBWApi: # pylint: disable=R0904
     def upload_airgapped_results(self, content):
         """POST request to /api/v2/cbw_scans/scripts to upload air gapped scanning script result"""
         response = self._request("POST", [ROUTE_AIRGAPPED_SCRIPTS], content)
-        if response.status_code != 204:
+        if response.status_code != 201:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -548,7 +552,7 @@ class CBWApi: # pylint: disable=R0904
         """GET request to /api/v3/compliance/servers/{server_id} to get all informations
         about a specific compliance asset"""
         response = self._request("GET", [ROUTE_COMPLIANCE_ASSETS, server_id])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error server id::{}".format(response.text))
             return None
         return self._cbw_parser(response)
@@ -556,7 +560,7 @@ class CBWApi: # pylint: disable=R0904
     def update_compliance_server(self, server_id, params):
         """PUT request to /api/v3/compliance/servers/{server_id} to update a compliance asset"""
         response = self._request("PUT", [ROUTE_COMPLIANCE_ASSETS, server_id], params)
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error server id::{}".format(response.text))
             return None
         return self._cbw_parser(response)
@@ -565,7 +569,7 @@ class CBWApi: # pylint: disable=R0904
         """PUT request to /api/v3/compliance/servers/{server_id}/recheck_rules to recheck
         the rules of a specific compliance asset"""
         response = self._request("PUT", [ROUTE_COMPLIANCE_ASSETS, server_id, 'recheck_rules'])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error server id::{}".format(response.text))
             return None
         return self._cbw_parser(response)
@@ -579,7 +583,7 @@ class CBWApi: # pylint: disable=R0904
         """GET request to /api/v3/compliance/rules/{server_id} to get all rules
         tested on a specific asset"""
         response = self._request("GET", [ROUTE_COMPLIANCE_RULES, server_id])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error server id::{}".format(response.text))
             return None
         return self._cbw_parser(response)
@@ -616,7 +620,7 @@ class CBWApi: # pylint: disable=R0904
     def recheck_servers(self, rule_id):
         """PUT request to /api/v3/compliance/rules/{rule_id}/recheck_servers to recheck a rule on all servers"""
         response = self._request("PUT", [ROUTE_COMPLIANCE_RULES, rule_id, 'recheck_servers'])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error rule id::{}".format(response.text))
             return None
         return self._cbw_parser(response)
@@ -629,7 +633,7 @@ class CBWApi: # pylint: disable=R0904
     def stored_credential(self, credential_id):
         """GET request to /api/v3/assets/credentials/{credential_id} to retrieve a set of stored credentials"""
         response = self._request("GET", [ROUTE_STORED_CREDENTIALS, credential_id])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error server id::{}".format(response.text))
             return None
         return self._cbw_parser(response)
@@ -671,7 +675,7 @@ class CBWApi: # pylint: disable=R0904
     def docker_image(self, docker_image_id):
         """GET request to /api/v3/assets/docker_images/{id} to retrieve an docker image"""
         response = self._request("GET", [ROUTE_DOCKER_IMAGES, docker_image_id])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error server id::{}".format(response.text))
             return None
         return self._cbw_parser(response)
@@ -714,7 +718,7 @@ class CBWApi: # pylint: disable=R0904
     def asset(self, asset_id):
         """GET request to /api/v3/assets/servers/<asset_id> to get a specific asset"""
         response = self._request("GET", [ROUTE_ASSETS, asset_id])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -723,7 +727,7 @@ class CBWApi: # pylint: disable=R0904
     def delete_asset(self, asset_id):
         """DELETE request to /api/v3/assets/servers/<asset_id> to delete a asset"""
         response = self._request("DELETE", [ROUTE_ASSETS, asset_id])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
@@ -737,7 +741,7 @@ class CBWApi: # pylint: disable=R0904
     def applicative_scan(self, applicative_scan_id):
         """GET request to /api/v3/assets/applicative_scans/{id} to retrieve an applicative scan"""
         response = self._request("GET", [ROUTE_APPLICATIVE_SCANS, applicative_scan_id])
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error server id::{}".format(response.text))
             return None
         return self._cbw_parser(response)
@@ -773,7 +777,7 @@ class CBWApi: # pylint: disable=R0904
     def fetch_compliance_airgapped_scripts(self, params=None):
         """GET request to /api/v2/compliances/scripts to fetch compliance scripts"""
         response = self._request("GET", [ROUTE_AIRGAPPED_COMPLIANCE_SCRIPTS], params)
-        if response.status_code != 200:
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
         return self._cbw_parser(response)
@@ -795,7 +799,31 @@ class CBWApi: # pylint: disable=R0904
     def server_reboot(self, server_id, params=None):
         """POST request to /api/v3/vulnerabilities/servers/<id>/reboot to reboot a server"""
         response = self._request("PATCH", [ROUTE_SERVERS, server_id, "reboot"], params)
-        if response.status_code != 200:
+        if not response.ok:
+            logging.error("Error::{}".format(response.text))
+            return None
+
+        return self._cbw_parser(response)
+
+    def discoveries(self, params=None):
+        """GET request to /api/v3/assets/discoveries to get a list of all discoveries"""
+        response = self._get_pages("GET", [ROUTE_DISCOVERY], params)
+
+        return response
+
+    def relaunch_discovery(self, discovery_id):
+        """PUT request to /api/v3/assets/discoveries/<discovery_id>/relaunch to get a specific discovery"""
+        response = self._request("PUT", [ROUTE_DISCOVERY, discovery_id, "relaunch"])
+        if not response.ok:
+            logging.error("Error::{}".format(response.text))
+            return None
+
+        return self._cbw_parser(response)
+
+    def delete_discovery(self, discovery_id):
+        """DELETE request to /api/v3/assets/discoveries/<discovery_id> to get a specific discovery"""
+        response = self._request("DELETE", [ROUTE_DISCOVERY, discovery_id])
+        if not response.ok:
             logging.error("Error::{}".format(response.text))
             return None
 
